@@ -647,8 +647,11 @@ proc affiche_main { w } {
 # Liste des boutons situs  droite
 #
    set m  $fbout.file.m
-   menubutton $fbout.file -text "Editer" -font $but_fnt -menu $m -relief raised
-   menu $m -tearoff 0
+   menubutton $fbout.file -text "Editer" -font $but_fnt -menu $m -relief raised \
+        -background $astk::ihm(couleur,valid)
+   menu $m -tearoff 0 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    $m add command -label "Fichier output" -underline 8 -font $but_fnt -command "editJobSel $fensuiv.ftx1.lbx output"
    $m add command -label "Fichier error"  -underline 8 -font $but_fnt -command "editJobSel $fensuiv.ftx1.lbx error"
    grid $fbout.file -row 0 -column 0 -sticky ew -pady 5
@@ -768,7 +771,9 @@ proc affiche_main { w } {
 # construit le popup menu
 #################################################################
 proc asjob_popup { fensuiv m } {
-   menu $m -tearoff 0 -bd 1
+   menu $m -tearoff 0 -bd 1 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    $m add command -label "Editer output" -font $astk::ihm(font,labmenuB) -command "editJobSel $fensuiv.ftx1.lbx output"
    #$m add command -label "Editer output.html BETA" -font $astk::ihm(font,labmenu) -command "editJobSel $fensuiv.ftx1.lbx output_html"
    $m add command -label "Editer error" -font $astk::ihm(font,labmenu)  -command "editJobSel $fensuiv.ftx1.lbx error"
@@ -778,7 +783,7 @@ proc asjob_popup { fensuiv m } {
    $m add command -label "Actualiser tous" -font $astk::ihm(font,labmenu)  -command "$fensuiv.bout.ac invoke"
    $m add separator
    $m add command -label "Supprimer" -font $astk::ihm(font,labmenu)  -command "$fensuiv.bout.su invoke"
-   $m add command -label "Interrompre USR1" -font $astk::ihm(font,labmenu)  -command "susp_job $fensuiv.ftx1.lbx"
+   $m add command -label "Arrter proprement" -font $astk::ihm(font,labmenu)  -command "susp_job $fensuiv.ftx1.lbx"
    $m add command -label "Purger flasheur" -font $astk::ihm(font,labmenu)  -command "purge_job"
 }
 
