@@ -588,7 +588,8 @@ proc check_exist_type { } {
             }
             if { ( $var != "surcharge" && $astk::profil($var,fich,$i,donnee) )
               || ( $var == "surcharge" && $astk::profil($var,fich,$i,donnee)
-                   && $astk::profil($var,fich,$i,resultat) == 0 ) } {
+                   && $astk::profil($var,fich,$i,resultat) == 0
+                   && $astk::profil(agla) != "oui" ) } {
                # serveur
                set srv $astk::inv(serv,$astk::profil($var,fich,$i,serv))
                # chemin du fichier
@@ -907,6 +908,14 @@ proc import_astk_serv { fich append } {
    }
    close $idp
    set astk::profil(memoire_aster) [expr $perc * $astk::profil(memoire) / 100]
+   # chemin de base
+   if { [file dirname $astk::profil(nom_profil)] != "." } {
+       foreach var { etude tests sources surcharge } {
+           if { $astk::profil(path_$var) == "" } {
+              set astk::profil(path_$var) [file dirname $astk::profil(nom_profil)]
+           }
+       }
+   }
    return $iret
 }
 
