@@ -110,7 +110,7 @@ proc ashare::file_prop { } {
    }
    append cmd "\""
    set serv $astk::inv(serv,$astk::sel(servname))
-   set cmd [ashare::subst_var $cmd $serv]
+   set cmd [ashare::subst_var $cmd]
    set iret [ashare::rexec_cmd $serv astk::config $cmd "" 0 retour_ls]
    set msg [ashare::mess ihm 172]
    append msg " :"
