@@ -311,7 +311,7 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
          if { [regexp -- {@D} $cmd] == 0 } {
             append cmd " -display @D"
          }
-         set cmd [ashare::subst_var $cmd $serv]
+         set cmd [ashare::subst_var $cmd]
          # retirer "-e ..."
          regsub -- {-e.*$} $cmd "" cmd
          puts $idexp "P xterm $cmd"
