@@ -122,6 +122,9 @@ proc fenEEC { fenetre_parent nongl } {
    set astk::ihm(ssong,$nongl) 1
    if { $astk::ihm(nbong,$nongl) > 1 } {
       set MenuButt [tk_optionMenu $fenetre_parent.titre.songl ongsel($nongl) $astk::ihm(tit,$nongl,1)]
+      $MenuButt configure \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
       $MenuButt entryconfigure 1 -font $astk::ihm(font,labbout) -command "choix_ongletM $nongl 1"
       set ashare::context($MenuButt,0) $astk::ihm(ctx,$nongl,1)
       for {set j 2} {$j <= $astk::ihm(nbong,$nongl)} {incr j} {
@@ -551,6 +554,9 @@ proc liste_machines { parent } {
    set pastrouve 1
    catch { destroy $parent.noeud }
    set MenuNoeud [tk_optionMenu $parent.noeud astk::profil(noeud) $astk::ihm(lnoeud,0)]
+   $MenuNoeud configure \
+       -foreground $astk::ihm(couleur,menu_foreground) \
+       -background $astk::ihm(couleur,menu_background)
    $MenuNoeud entryconfigure 0 -font $astk::ihm(font,lablst) -command "change_noeud"
    for {set j 1} {$j < $astk::ihm(nb_noeud)} {incr j} {
       $MenuNoeud add radiobutton
@@ -579,6 +585,9 @@ proc liste_versions { parent } {
       if { $astk::profil(version) == $astk::ihm(lvers,0) } { set pastrouve 0 }
    }
    set MenuVers [tk_optionMenu $parent.vers astk::profil(version) $astk::ihm(lvers,0)]
+   $MenuVers configure \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    $MenuVers entryconfigure 0 -font $astk::ihm(font,lablst)
    for {set j 1} {$j < $astk::ihm(nb_vers)} {incr j} {
       $MenuVers add radiobutton
