@@ -94,6 +94,9 @@ proc liste_fich {tfic pos_debut var} {
          set ideb 3
       }
       set m [tk_optionMenu $tfic.lig($i,type) astk::profil($var,fich,$i,type) $astk::UL($var,$ideb,nom)]
+      $m configure \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
       $m entryconfigure 0 -font $astk::ihm(font,lablst) -command "set astk::profil($var,fich,$i,UL) $astk::UL($var,$ideb,num)"
       incr ideb
       set ind 0
@@ -108,6 +111,9 @@ proc liste_fich {tfic pos_debut var} {
       def_context $tfic.lig($i,type) 304
    # serv
       set m2 [tk_optionMenu $tfic.lig($i,serv) astk::profil($var,fich,$i,serv) $astk::config(-1,nom)]
+      $m2 configure \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
       $m2 entryconfigure 0 -font $astk::ihm(font,lablst)
       for {set j 0} {$j < $astk::config(nb_serv)} {incr j} {
          set j1 [expr $j + 1]
@@ -316,12 +322,12 @@ proc liste_icone { fenetre_icone fenetre_liste var } {
    }
 
 # flches haut et bas
-   if { $var == "etude" } {
+   if { $var == "etude" || $var == "sources" || $var == "tests" } {
       button $fenetre_icone.haut -image [image create photo -file $astk::icon(uparrow)] \
-            -bd 0 -command "move_act $fenetre_liste -1"
+          -bd 0 -command "move_act $fenetre_liste -1"
       pack $fenetre_icone.haut -pady 3 -padx 3
       button $fenetre_icone.bas -image [image create photo -file $astk::icon(downarrow)] \
-            -bd 0 -command "move_act $fenetre_liste +1"
+          -bd 0 -command "move_act $fenetre_liste +1"
       pack $fenetre_icone.bas -pady 3 -padx 3
    }
 # bind
@@ -663,7 +669,9 @@ proc valeur_defaut { } {
 # en cas d'insertion ou suppression voir aussi tkselecteur.CreateMenu
 #################################################################
 proc create_popup { m } {
-   menu $m -tearoff 0 -bd 1
+   menu $m -tearoff 0 -bd 1 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    $m add command -label [ashare::mess ihm 169] -font $astk::ihm(font,labmenuB) -command {ashare::file_open typ}
    $m add command -label [ashare::mess ihm 171] -font $astk::ihm(font,labmenu)  -command {ashare::file_open edit}
    $m add command -label [ashare::mess ihm 179] -font $astk::ihm(font,labmenu)  -command {ashare::file_print_to}
@@ -680,7 +688,9 @@ proc create_popup { m } {
 proc complete_popup { pop } {
    set mopw $pop.opw
    catch { destroy $mopw }
-   menu $mopw -tearoff 0 -bd 1
+   menu $mopw -tearoff 0 -bd 1 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
 # tableau inverse
    for {set j 0} {$j < $astk::outils(nb)} {incr j} {
       set astk::inv(outil,$astk::outils($j,nom)) $j
