@@ -464,6 +464,9 @@ proc outils_conf_list { fen } {
       $MenuOut entryconfigure 0 -font $astk::ihm(font,labmenu) -command "add_outil $fen $MenuOut"
       pack $fen.haut.choix_out.outil
    }
+   $MenuOut configure \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    button $fen.haut.help -image [image create photo -file $astk::icon(help)] \
          -bd 0 -command "grab release $fen ; aff_aide . 190"
    pack $fen.haut.help -anchor ne -side right
