@@ -82,22 +82,11 @@ proc pre_traite_argv { } {
 #################################################################
 proc init_gene { root } {
    global env tcl_platform
-# Ensures that the table library extension is loaded
-#    set table(library) Tktable[info sharedlibextension]
-#    if {
-#       [string match {} [info commands table]]
-#       && [catch {package require Tktable} err]
-#       && [catch {load [file join [pwd] $table(library)]} err]
-#       && [catch {load [file join [pwd] .. unix $table(library)]} err]
-#       && [catch {load [file join [pwd] .. win $table(library)]} err]
-#    } {
-#       error $err
-#    }
-#    package require Tktable
 
 # Initialisation des variables partages
    # mettre dbg<>0 pour tracer
    set ashare::dbg 0
+   set ashare::fen_log 0
 
    # sortie apres les verifs ?
    set astk::check_quit 0
@@ -122,7 +111,18 @@ proc init_gene { root } {
    }
    set astk::astk_version [join [lrange $lv 0 $fin] .]
 
+   # definition des frames
+   set astk::ihm(menu)        .bar
+   set astk::ihm(fenetre)     .fen.fenetre
+   set astk::ihm(satellite)   .fen.satellite
+   set astk::ihm(popup)       .popup
+   set astk::ihm(status)      .fen.status
+   set astk::ihm(asjob)       .asjob
+   set astk::ihm(log)         .log
+   set astk::ihm(interrompre) .interrompre
+
    # chargement des modules
+   set astk::ihm(extensions) { }
    load_modules
 
 # plate-forme
@@ -214,16 +214,6 @@ proc init_gene { root } {
    # slection
    init_sel
 
-   # definition des frames
-   set astk::ihm(menu)        .bar
-   set astk::ihm(fenetre)     .fen.fenetre
-   set astk::ihm(satellite)   .fen.satellite
-   set astk::ihm(popup)       .popup
-   set astk::ihm(status)      .fen.status
-   set astk::ihm(asjob)       .asjob
-   set astk::ihm(log)         .log
-   set astk::ihm(interrompre) .interrompre
-
    # mode de lancement d'une tude
    set astk::ihm(mode,run) "run"
    set astk::ihm(mode,dbg) "dbg"
@@ -297,8 +287,7 @@ proc init_sel { } {
 
 #################################################################
 proc load_modules { } {
-# icones
-   init_icon
+   global env
 # Chargement des modules astk
    set modul { init_env unites_logiques \
                init_agla \
@@ -354,14 +343,36 @@ proc load_modules { } {
    }
 
 # Chargement des modules externes
-   set mod { { BWidget BWidget-1.7.0 } }
+# TKPNG_ROOT contient pkgIndex.tcl et la libtkpng(VERS).so correspondante
+   set tkpng_root not_defined
+   catch { set tkpng_root $env(TKPNG_ROOT) }
+   set mod { "BWidget BWidget-1.7.0 1" }
+   lappend mod "tkpng $tkpng_root 0"
    set nmod [llength $mod]
    for {set i 0} {$i < $nmod} {incr i} {
       set modi [lindex $mod $i]
       set bdir [file join $ashare::root [lindex $modi 1]]
       lappend ::auto_path $bdir
-      namespace inscope :: package require [lindex $modi 0]
+      set iret 4
+      catch {
+          namespace inscope :: package require [lindex $modi 0]
+          lappend astk::ihm(extensions) [lindex $modi 0]
+          set iret 0
+      }
+      if { $iret != 0 } {
+         if { [lindex $modi 2] == 1 } {
+            ashare::log "<ERREUR 000> Required module not found : [lindex $modi 0]"
+            ashare::log "             searched in $bdir"
+            ashare::my_exit 4
+         } else {
+            ashare::log "<INFO> Optional module not found : [lindex $modi 0]"
+            ashare::log "       searched in $bdir"
+         }
+      }
    }
+
+# icones
+   init_icon
 }
 
 # icones
@@ -371,24 +382,32 @@ proc init_icon { {theme crystal} } {
                dir file up refresh comp \
                help help_sans salome \
                uparrow downarrow }
-   set astk::icon(__list__) { crystal vaio }
+
+   # default icons
+   set prefix "crystalsvg_22_"
+   set extension ".gif"
+   set ficon { folder_open fileopen filenew button_cancel edit \
+               folder empty up reload openterm \
+               help help salome \
+               1uparrow 1downarrow }
+   
    if { $theme == "vaio" } {
       set prefix "vaio_"
-      set extension ".gif"
       set ficon { openRS openS newS deleteS editS \
                   dirS fileS upS refreshS compS \
                   helpS sans_helpB salome \
                   uparrow downarrow }
-   } elseif { $theme == "crystal" } {
-      set prefix "crystalsvg_22_"
-      set extension ".gif"
+   } elseif { $theme == "lucid_amb" } {
+      set prefix "ambiance_"
       set ficon { folder_open fileopen filenew button_cancel edit \
                   folder empty up reload openterm \
                   help help salome \
-                  1uparrow 1downarrow }
-   } else {
-      init_icon [lindex $astk::icon(__list__) 0]
-      return
+                  uparrow downarrow }
+      if { [lsearch $astk::ihm(extensions) tkpng] >= 0 } {
+          set extension ".png"
+      } else {
+          ashare::log "<WARNING> tkpng required to use full colors icons of the theme: lucid_amb"
+      }
    }
    # add iconwindow
    append icons "iconwindow"
@@ -415,12 +434,41 @@ proc init_couleur { {act "setpal"} } {
 # variable du widget radio du menu
    set astk::ihm(style,couleur_var) [ashare::mess ihm 325]
 # initialisation des valeurs prdfinies
+   # avant-plan gnral
+   set astk::ihm(couleur,foreground) black
+   # avant/arrire-plan gnral
+      set astk::ihm(couleur,menu_foreground) black
+   set astk::ihm(couleur,background) "#E2E2E2"
+   # arrire-plan menu
+   set astk::ihm(couleur,menu_background) "#E2E2E2"
+   # arrire-plan entry
+   set astk::ihm(couleur,entry_background) "#FFFFFF"
+   # valid
+   set astk::ihm(couleur,valid) "#E3D4FF"
+   # annulation
+   set astk::ihm(couleur,suppr) "#EA6B6B"
+   # suppression
+   set astk::ihm(couleur,annul) "#E3D4FF"
+   # bouton
+   set astk::ihm(couleur,onglet_inactif) "#E3D4FF"
+   # bouton actif
+   set astk::ihm(couleur,onglet_actif) "#AB8EFF"
+   # suivi
+   set astk::ihm(couleur,suivi) "#E3D4FF"
+   # lancement
+   set astk::ihm(couleur,lancement) "#E3D4FF"
+   # listes
+   set astk::ihm(couleur,liste) "#E3D4FF"
+   set astk::ihm(couleur,mode_lancement) "#E3D4FF"
    if { $astk::ihm(style,couleur) == "nostalgique" } {
       set astk::ihm(style,couleur_var) [ashare::mess ihm 326]
       # avant-plan gnral
       set astk::ihm(couleur,foreground) black
       # arrire-plan gnral
       set astk::ihm(couleur,background) "#FFDEAD"
+      # avant/arrire-plan menu
+      set astk::ihm(couleur,menu_foreground) black
+      set astk::ihm(couleur,menu_background) "#FFDEAD"
       # arrire-plan entry
       set astk::ihm(couleur,entry_background) "#FFFFF0"
       # valid
@@ -446,6 +494,9 @@ proc init_couleur { {act "setpal"} } {
       set astk::ihm(couleur,foreground) "#404040"
       # arrire-plan gnral
       set astk::ihm(couleur,background) "#f0f0ff"
+      # avant/arrire-plan menu
+      set astk::ihm(couleur,menu_foreground) "#404040"
+      set astk::ihm(couleur,menu_background) "#f0f0ff"
       # arrire-plan entry
       set astk::ihm(couleur,entry_background) "#ffffff"
       # valid
@@ -465,30 +516,34 @@ proc init_couleur { {act "setpal"} } {
       # listes
       set astk::ihm(couleur,liste) "#dee0e5"
       set astk::ihm(couleur,mode_lancement) "#dee0e5"
-   } else {
+   } elseif { $astk::ihm(style,couleur) == "lucid_amb" } {
+      set astk::ihm(style,couleur_var) [ashare::mess ihm 391]
       # avant-plan gnral
-      set astk::ihm(couleur,foreground) black
+      set astk::ihm(couleur,foreground) "#000000"
       # arrire-plan gnral
-      set astk::ihm(couleur,background) "#E2E2E2"
+      set astk::ihm(couleur,background) "#f0ebe2"
+      # avant/arrire-plan menu
+      set astk::ihm(couleur,menu_foreground) "#dfd8c6"
+      set astk::ihm(couleur,menu_background) "#3c3b37"
       # arrire-plan entry
-      set astk::ihm(couleur,entry_background) "#FFFFFF"
+      set astk::ihm(couleur,entry_background) "#ffffff"
       # valid
-      set astk::ihm(couleur,valid) "#E3D4FF"
+      set astk::ihm(couleur,valid) "#f0ebe2"
       # annulation
-      set astk::ihm(couleur,suppr) "#EA6B6B"
+      set astk::ihm(couleur,suppr) "#f06e34"
       # suppression
-      set astk::ihm(couleur,annul) "#E3D4FF"
+      set astk::ihm(couleur,annul) "#af9f89"
       # bouton
-      set astk::ihm(couleur,onglet_inactif) "#E3D4FF"
+      set astk::ihm(couleur,onglet_inactif) "#cfc3ad"
       # bouton actif
-      set astk::ihm(couleur,onglet_actif) "#AB8EFF"
+      set astk::ihm(couleur,onglet_actif) "#f9e4da"
       # suivi
-      set astk::ihm(couleur,suivi) "#E3D4FF"
+      set astk::ihm(couleur,suivi) "#d8cebf"
       # lancement
-      set astk::ihm(couleur,lancement) "#E3D4FF"
+      set astk::ihm(couleur,lancement) "#c2b4a2"
       # listes
-      set astk::ihm(couleur,liste) "#E3D4FF"
-      set astk::ihm(couleur,mode_lancement) "#E3D4FF"
+      set astk::ihm(couleur,liste) "#cfc3ad"
+      set astk::ihm(couleur,mode_lancement) "#c2b4a2"
    }
 # surcharge par couleur perso
    if { $astk::ihm(style,couleur) == "perso" } {
