@@ -465,6 +465,9 @@ proc cohe_fich { } {
             incr err
          }
       }
+      if { $astk::profil(serv_$var) > [expr $astk::config(nb_serv) - 1] } {
+         set astk::profil(serv_$var) -1
+      }
    }
    if { $err > 0 } {
       return 2
