@@ -74,6 +74,9 @@ proc Opt_conf_list { fen } {
       set MenuOptNoeud [tk_optionMenu $fen.haut.choix_serv.noeud serv_conf [ashare::mess ihm 70]]
       $MenuOptNoeud entryconfigure 0 -font $astk::ihm(font,labmenu) -command "add_serv $fen $MenuOptNoeud"
    }
+   $MenuOptNoeud configure \
+      -foreground $astk::ihm(couleur,menu_foreground) \
+      -background $astk::ihm(couleur,menu_background)
 #
    $fen.haut.choix_serv.noeud configure -font $astk::ihm(font,labmenu) -bg $astk::ihm(couleur,liste)
    pack $fen.haut.choix_serv.noeud
@@ -185,6 +188,9 @@ proc Opt_conf_serv {fen nserv} {
       }
    }
    set MenuRec [tk_optionMenu $fen.f.recup.ch rec_bid($serv) $rlist(0)]
+   $MenuRec configure \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    $MenuRec entryconfigure 0 -font $astk::ihm(font,labmenu) -command "set astk::config($serv,recup) $rval(0)"
    for {set j 1} {$j < 3} {incr j} {
       $MenuRec add radiobutton
