@@ -104,15 +104,19 @@ proc ashare::selecteur {srv_OUT dir_OUT typ_OUT srv_IN dir_IN typ_IN {args_sup "
 #   @f = nom du fichier sans le rpertoire
 #   @R = rpertoire contenant le fichier slectionn
 #################################################################
-proc ashare::subst_var { cmd serv } {
+proc ashare::subst_var { cmd } {
    regsub -all "@D" $cmd $ashare::DISPLAY cmd
    set name $astk::sel(filename)
 #   if { $name != "" } {
    set dir  [file dirname $name]
    set base [file tail $name]
-   regsub -all "@F" $cmd $name cmd
-   regsub -all "@f" $cmd $base cmd
-   regsub -all "@R" $cmd $dir cmd
+   # on ne remplace qui si suivi d'un espace ou fin de ligne
+   regsub -all "@F " $cmd "$name " cmd
+   regsub -all "@f " $cmd "$base " cmd
+   regsub -all "@R " $cmd "$dir " cmd
+   regsub -all "@F\$" $cmd "$name " cmd
+   regsub -all "@f\$" $cmd "$base " cmd
+   regsub -all "@R\$" $cmd "$dir " cmd
 #   }
    return $cmd
 }
@@ -146,7 +150,7 @@ proc ashare::rexec_cmd { serv cfg prog args bg output {parent ""}} {
    }
 # substitution des variables et arguments
    append prog " $args"
-   set cmd [ ashare::subst_var $prog $serv]
+   set cmd [ ashare::subst_var $prog ]
 #
    ashare::mess info 44 $config($serv,nom_complet) $cmd $serv
    if { $serv >= 0 } {
