@@ -435,7 +435,8 @@ proc tkgetdir::tk_getDirectory {cfg args} {
    event add <<RetEnt>> <Return> <KP_Enter>
 
    if { $tkgetdir::active_menu } {
-      frame $tkgetdir::dirsel.f0 -relief raised -borderwidth 1
+      frame $tkgetdir::dirsel.f0 -relief raised -borderwidth 0 \
+        -background $astk::ihm(couleur,menu_background)
       pack $tkgetdir::dirsel.f0 -fill x -side top -anchor nw
    }
    frame $tkgetdir::dirsel.f1 -relief flat -borderwidth 0
@@ -453,23 +454,33 @@ proc tkgetdir::tk_getDirectory {cfg args} {
    pack $tkgetdir::dirsel.f5 -fill x
 
    menubutton $tkgetdir::dirsel.f1.mach -relief raised -indicatoron 1 -anchor w \
-           -menu $tkgetdir::dirsel.f1.mach.m
-   menu $tkgetdir::dirsel.f1.mach.m -tearoff 0
+           -menu $tkgetdir::dirsel.f1.mach.m \
+           -foreground $astk::ihm(couleur,foreground) \
+           -background $astk::ihm(couleur,liste)
+   menu $tkgetdir::dirsel.f1.mach.m -tearoff 0 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    for {set j -1} {$j < $tkgetdir::config(nb_serv)} {incr j} {
       $tkgetdir::dirsel.f1.mach.m add command -label $tkgetdir::config($j,nom) \
           -command "set tkgetdir::icurmach $j ; tkgetdir::ShowDir $tkgetdir::config($j,home) ; $tkgetdir::dirsel.f3.chosen delete 0 end ; $tkgetdir::dirsel.f1.mach configure -text $tkgetdir::config($j,nom)"
    }
-    $tkgetdir::dirsel.f1.mach configure -text $tkgetdir::config($tkgetdir::icurmach,nom)
+   $tkgetdir::dirsel.f1.mach configure -text $tkgetdir::config($tkgetdir::icurmach,nom)
    label $tkgetdir::dirsel.f1.lab -text $tkgetdir::msg(ldir)
    menubutton $tkgetdir::dirsel.f1.dir -relief raised -indicatoron 1 -anchor w \
-           -menu $tkgetdir::dirsel.f1.dir.m
+           -menu $tkgetdir::dirsel.f1.dir.m \
+           -foreground $astk::ihm(couleur,foreground) \
+           -background $astk::ihm(couleur,liste)
    # popup des rpertoires
-   menu $tkgetdir::dir_popup -tearoff 0 -bd 1
+   menu $tkgetdir::dir_popup -tearoff 0 -bd 1 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    $tkgetdir::dir_popup add command -label [ashare::mess ihm 341] -font $astk::ihm(font,labmenuB) -state disabled -foreground $astk::ihm(couleur,background) -background $astk::ihm(couleur,foreground)
    $tkgetdir::dir_popup add command -label [ashare::mess ihm 33] -font $astk::ihm(font,labmenu) -command {tkgetdir::DirConf}
    bind $tkgetdir::dirsel.f1.dir <3> {tk_popup $tkgetdir::dir_popup %X %Y}
    
-   menu $tkgetdir::dirsel.f1.dir.m -tearoff 0
+   menu $tkgetdir::dirsel.f1.dir.m -tearoff 0 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
    button $tkgetdir::dirsel.f1.cmp -image b_cmp -command {tkgetdir::OpenTerm}
    button $tkgetdir::dirsel.f1.ref -image b_ref -command {tkgetdir::ShowDir [$tkgetdir::dirsel.f1.dir cget -text]}
    button $tkgetdir::dirsel.f1.up  -image b_up  -command {tkgetdir::UpDir}
@@ -544,15 +555,23 @@ proc tkgetdir::tk_getDirectory {cfg args} {
       }
    # barre de menu
       # fichier
-      menubutton $tkgetdir::dirsel.f0.fic -font $astk::ihm(font,labmenu) -text [ashare::mess ihm 26] -underline 0 -menu $tkgetdir::dirsel.f0.fic.mnu
+      menubutton $tkgetdir::dirsel.f0.fic -font $astk::ihm(font,labmenu) -text [ashare::mess ihm 26] \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background) \
+        -underline 0 -menu $tkgetdir::dirsel.f0.fic.mnu
       pack $tkgetdir::dirsel.f0.fic -side left
       tkgetdir::CreateMenu $tkgetdir::dirsel.f0.fic.mnu
       $tkgetdir::dirsel.f0.fic.mnu add separator
       $tkgetdir::dirsel.f0.fic.mnu add command -font $astk::ihm(font,labmenu) -label [ashare::mess ihm 32] -command {$tkgetdir::dirsel.f4.cancel invoke}
       # affichage
-      menubutton $tkgetdir::dirsel.f0.aff -font $astk::ihm(font,labmenu) -text [ashare::mess ihm 197] -underline 0 -menu $tkgetdir::dirsel.f0.aff.mnu
+      menubutton $tkgetdir::dirsel.f0.aff -font $astk::ihm(font,labmenu) -text [ashare::mess ihm 197] \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background) \
+        -underline 0 -menu $tkgetdir::dirsel.f0.aff.mnu
       pack $tkgetdir::dirsel.f0.aff -side left
-      menu $tkgetdir::dirsel.f0.aff.mnu -tearoff 0 -bd 1
+      menu $tkgetdir::dirsel.f0.aff.mnu -tearoff 0 -bd 1 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
       $tkgetdir::dirsel.f0.aff.mnu add checkbutton -font $astk::ihm(font,labmenu) -label [ashare::mess ihm 198] \
          -variable tkgetdir::pref(fic_cach) -command {tkgetdir::ModifArgs fic_cach $tkgetdir::pref(fic_cach)}
       $tkgetdir::dirsel.f0.aff.mnu add checkbutton -font $astk::ihm(font,labmenu) -label [ashare::mess ihm 321] \
@@ -568,9 +587,14 @@ proc tkgetdir::tk_getDirectory {cfg args} {
       $tkgetdir::dirsel.f0.aff.mnu add command -font $astk::ihm(font,labmenu) -label [ashare::mess ihm 203] -command {tkgetdir::SauvePrefs}
       
       # aide
-      menubutton $tkgetdir::dirsel.f0.help -font $astk::ihm(font,labmenu) -text [ashare::mess ihm 105] -menu $tkgetdir::dirsel.f0.help.mnu
+      menubutton $tkgetdir::dirsel.f0.help -font $astk::ihm(font,labmenu) -text [ashare::mess ihm 105] \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background) \
+        -menu $tkgetdir::dirsel.f0.help.mnu
       pack $tkgetdir::dirsel.f0.help -side right
-      menu $tkgetdir::dirsel.f0.help.mnu -tearoff 0 -bd 1
+      menu $tkgetdir::dirsel.f0.help.mnu -tearoff 0 -bd 1 \
+        -foreground $astk::ihm(couleur,menu_foreground) \
+        -background $astk::ihm(couleur,menu_background)
       
       if { $tkgetdir::bsf } {
          $tkgetdir::dirsel.f0.help.mnu add command -font $astk::ihm(font,labmenu) -label "[ashare::mess ihm 196]..." -command {show_fen $astk::ihm(log) force}
