@@ -29,11 +29,14 @@ Manage backward compatibility for astk < 1.6.0
 import sys
 import re
 import os.path as osp
-from warnings import warn
+from warnings import warn, simplefilter
 
 from asrun.common.i18n import _
 
 
+# DeprecationWarning are ignored in python2.7 by default
+simplefilter('default')
+
 dict_serv = {
     'as_info'         : '--info',
     'as_edit'         : '--edit',
@@ -89,7 +92,7 @@ def change_argv(oldargv):
         if d.get(old) is not None:
             argv[d[old]] = new
 
-    #pylint: disable=E1103
+    #pylint: disable-msg=E1103
     # rcdir=xxx previously accepted a suffix, cause of confusion
     rcdir = get_option_value(argv, "--rcdir")
     rcdir0 = rcdir
@@ -128,7 +131,8 @@ def parse_config(*args, **kwargs):
 
 # 1.8.0 > 1.8.1
 def get_timeout(prof):
-    warn('get_timeout is now a method of ASTER_PROFIL object', DeprecationWarning, stacklevel=2)
+    warn('get_timeout is now a method of ASTER_PROFIL object', DeprecationWarning,
+        stacklevel=2)
     return prof.get_timeout()
 
 def add_param(prof, dict_para):
@@ -140,3 +144,11 @@ def get_hostrc(run, prof):
     warn('get_hostrc moved to asrun.repart', DeprecationWarning, stacklevel=2)
     from asrun.repart import get_hostrc
     return get_hostrc(run, prof)
+
+# 1.8.3 > 1.8.4
+def bwc_edit_args(args):
+    if len(args) > 4:
+        warn("'as_run --edit' does not support display argument anymore",
+            DeprecationWarning, stacklevel=2)
+    return args[:4]
+
