@@ -46,7 +46,8 @@ class BatchSystem(object):
         self.prof   = prof
         self.script = script
         self.jn = os.getpid()
-        self.btc_file = get_tmpname(self.run, self.run['tmp_user'], basename='btc_file')
+        self.btc_file = get_tmpname(self.run, self.run['tmp_user'],
+                                    basename='btc_%s' % prof['nomjob'][0])
 
 
     def build_dict_info(self):
@@ -54,13 +55,15 @@ class BatchSystem(object):
         """
         dico = {
             'nomjob'    : self.prof['nomjob'][0],
-            'tpsjob'    : self.prof['tpsjob'][0],        # in minutes
+            'tpsjob'    : self.prof['tpsjob'][0],     # in minutes
             'tpmax'     : self.prof.args['tpmax'],    # in seconds
             'memjob'    : self.prof['memjob'][0],
             'clasgr'    : self.prof['classe'][0],
             'depart'    : self.prof['depart'][0],
             'batch_ini' : self.run.get('batch_ini'),
             'batch_sub' : self.run.get('batch_sub'),
+            'mpi_nbcpu' : self.prof['mpi_nbcpu'][0],
+            'mpi_nbnoeud': self.prof['mpi_nbnoeud'][0],
         }
         if dico['clasgr'] != '' and dico['clasgr'] in self.run.get('batch_queue_group', '').split():
             dico['classe'] = self.run.get('batch_queue_%s' % dico['clasgr'], '')
@@ -108,7 +111,10 @@ class BatchSystem(object):
         content = txt % self.dict_info
         open(self.btc_file, 'w').write(content)
         iret, jobid, queue = self.submit()
-        os.remove(self.btc_file)
+        try:
+            os.remove(self.btc_file)
+        except OSError:
+            pass
         return iret, jobid, queue
 
 
@@ -124,6 +130,7 @@ class LSF(BatchSystem):
             'error'     : os.path.join(self.run['flasheur'], '%s.e%%J' % self.dict_info['nomjob']),
             'output'    : os.path.join(self.run['flasheur'], '%s.o%%J' % self.dict_info['nomjob']),
         })
+        self.dict_info['tpsjob'] = int(self.dict_info['tpsjob'])
 
 
     def change_script(self):
@@ -134,6 +141,8 @@ class LSF(BatchSystem):
              "#BSUB -M %(memjob)s",
              "#BSUB -e %(error)s",
              "#BSUB -o %(output)s"]
+        if self.dict_info.get('mpi_nbcpu'):
+            txt.append("""#BSUB -n %(mpi_nbcpu)s""")
         if self.dict_info.get('classe'):
             txt.append('''#BSUB -q "%(classe)s"''')
         if self.dict_info.get('depart'):
@@ -175,6 +184,8 @@ class PBS(BatchSystem):
                     "#PBS -l cput=%(tpmax)s",
                     "#PBS -l mem=%(memjob)skb",])
         # output/error will be named %(nomjob).o%(jobid) in the directory where qsub has been run
+        if self.dict_info.get('mpi_nbcpu'):
+            txt.append("""#PBS -l nodes=%(mpi_nbcpu)s""")
         if self.dict_info.get('classe'):
             txt.append('''#PBS -q "%(classe)s"''')
         if self.dict_info.get('depart'):
@@ -234,6 +245,8 @@ class SGE(BatchSystem):
                "#$ -l cpu=%(tpmax)s,s_rss=%(memjob)sK",
                "#$ -e %(error)s",
                "#$ -o %(output)s"]
+        #if self.dict_info.get('mpi_nbcpu'):
+            #txt.append("""#$ -l num_cpu=%(mpi_nbcpu)s""")
         if self.dict_info.get('classe'):
             txt.append('''#$ -q "%(classe)s"''')
         if self.dict_info.get('depart'):
