@@ -36,7 +36,7 @@ def SetParser(run):
     acts_descr = {
         'insert_in_db' : {
             'method' : Insert,
-            'syntax' : '[export_file]',
+            'syntax' : 'export_file',
             'help'   : _(u'prepare the profile to insert an execution into a database.')
         },
     }
@@ -62,7 +62,7 @@ def Insert(run, *args):
     if not on_machref:
         run.Mess(_(u'Only available on the AGLA machine'), '<F>_AGLA_ERROR')
     if not run.config.get('astketud'):
-        run.Mess(_(u"'astketud' is not defined in 'config' file."), '<F>_AGLA_ERROR')
+        run.Mess(_(u"'astketud' is not defined in 'agla' configuration file."), '<F>_AGLA_ERROR')
     
     # 1. copy export file
     jn = run['num_job']
