@@ -27,7 +27,6 @@ import re
 import copy
 import time
 from glob import glob
-from types import ListType, TupleType
 
 from asrun.common.i18n import _
 from asrun.mystring     import print3, ufmt
@@ -526,13 +525,7 @@ class ASTER_BUILD:
         reptrav = os.path.join(repdest, self.conf['REPPY'][0], '__tmp__')
         prev = os.getcwd()
         # ----- check that files and directories in kargs exist
-        for occ in kargs.values():
-            obj = occ
-            if not type(occ) in (ListType, TupleType):
-                obj = [occ]
-            for rep in obj:
-                if not self.run.Exists(rep):
-                    self._mess(ufmt(_(u'path does not exist : %s'), rep), '<E>_FILE_NOT_FOUND')
+        self._check_file_args(kargs.values())
         if not os.path.isdir(repdest):
             iret = self.run.MkDir(repdest, verbose=True)
         self.run.CheckOK()
@@ -590,8 +583,8 @@ class ASTER_BUILD:
             self._mess(_(u"copy user's python source files"))
             # ----- python source given by user
             lobj = kargs['py']
-            if not type(lobj) in (ListType, TupleType):
-                lobj = [kargs['py'], ]
+            if not type(lobj) in (list, tuple):
+                lobj = [lobj, ]
             for occ in lobj:
                 obj = occ
                 if self.run.IsRemote(occ):
@@ -706,13 +699,7 @@ class ASTER_BUILD:
         if cmde == '':
             cmde = os.path.join(REPREF, self.conf['BINCMDE'][0])
         # ----- check that files and directories in kargs exist
-        for occ in kargs.values():
-            obj = occ
-            if not type(occ) in (ListType, TupleType):
-                obj = [occ]
-            for rep in obj:
-                if not self.run.Exists(rep):
-                    self._mess(ufmt(_(u'path does not exist : %s'), rep), '<E>_FILE_NOT_FOUND')
+        self._check_file_args(kargs.values())
         if not os.path.isdir(cmde):
             iret = self.run.MkDir(cmde, verbose=True)
         if not os.path.isdir(reptrav):
@@ -738,8 +725,8 @@ class ASTER_BUILD:
             self._mess(_(u"copy user's catalogues"))
             # ----- catapy given by user
             lobj = kargs['capy']
-            if not type(obj) in (ListType, TupleType):
-                lobj = [kargs['capy'], ]
+            if not type(lobj) in (list, tuple):
+                lobj = [lobj, ]
             for occ in lobj:
                 obj = occ
                 if self.run.IsRemote(occ):
@@ -931,13 +918,7 @@ sys.exit(iret)
                         '<E>_PROGRAM_ERROR')
         
         # ----- check that files and directories in kargs exist
-        for occ in kargs.values():
-            obj = occ
-            if not type(occ) in (ListType, TupleType):
-                obj = [occ]
-            for rep in obj:
-                if not self.run.Exists(rep):
-                    self._mess(ufmt(_(u'path does not exist : %s'), rep), '<E>_FILE_NOT_FOUND')
+        self._check_file_args(kargs.values())
         if not os.path.isdir(reptrav):
             iret = self.run.MkDir(reptrav, verbose=True)
         self.run.CheckOK()
@@ -956,7 +937,7 @@ sys.exit(iret)
             fo = open('surch.cata', 'w')
             # ----- catapy given by user
             lobj = kargs['cata']
-            if not type(obj) in (ListType, TupleType):
+            if not type(lobj) in (list, tuple):
                 lobj = [kargs['cata'], ]
             for occ in lobj:
                 obj = occ
@@ -1255,6 +1236,22 @@ FIN()
         return mod, rep
 
 
+    def _check_file_args(self, args):
+        """Check that files and directories in arguments exist."""
+        if type(args) not in (list,tuple):
+            args = [args, ]
+        for occ in args:
+            obj = occ
+            if not type(occ) in (list, tuple):
+                obj = [occ,]
+            for rep in obj:
+                if type(rep) not in (str, unicode):
+                    continue
+                if not self.run.Exists(rep):
+                    self._mess(ufmt(_(u'path does not exist : %s'), rep),
+                        '<E>_FILE_NOT_FOUND')
+
+
 def get_txt_capy(capy):
     """On utilise le fait qu'il n'y a rien après la définition de l'OPER, PROC ou MACRO.
     """
@@ -1483,3 +1480,4 @@ def unigest2dict(funig, conf, with_fordepla=False):
                 dico['f'].append(os.path.join(conf['SRCFOR'][0], old, nam))
     fo.close()
     return dico
+
