@@ -137,6 +137,7 @@ class ASTER_CALCUL:
                 self.serv = 'parametric_study'
             else:
                 self.serv = 'study'
+        self.prof['service'] = self.serv
         self.run.DBG("service name : %s" % self.serv)
         if self.serv not in self._supported_services:
             self.error(_(u'Unknown service : %s') % self.serv)
@@ -270,9 +271,6 @@ class ASTER_CALCUL:
 
         btc = r"""#!/bin/sh
 
-# tous les fichiers/répertoires seront privés
-umask 077
-
 %(str_display)s
 %(str_aster_profile)s
 %(str_pid)s
@@ -312,7 +310,7 @@ egrep -- '--- DIAGNOSTIC JOB :' %(rep_trav)s/%(nomjob)s.$num_job.fort.6.%(m)s |
         })
 
         open(fbtc, 'w').write(btc % dict_btc)
-        os.chmod(fbtc, 0700)
+        os.chmod(fbtc, 0755)
         time.sleep(0.5)
 
     def soumbtc_batch(self, fbtc):
@@ -381,7 +379,6 @@ egrep -- '--- DIAGNOSTIC JOB :' %(rep_trav)s/%(nomjob)s.$num_job.fort.6.%(m)s |
                 print3(_(u"Connection failure to %s (from %s)") % (node, self.prof['serveur'][0]))
                 return 6, '', 'unknown'
 
-        os.umask(0077)
         kret, output = self.run.Shell(cmd, mach=node, bg=True)
 
         return 0, self.jobid, 'interactif'
@@ -393,6 +390,10 @@ egrep -- '--- DIAGNOSTIC JOB :' %(rep_trav)s/%(nomjob)s.$num_job.fort.6.%(m)s |
         # ----- copy and read .export, build dict for formatting
         self.build_dict_info(options)
 
+        if self.run.get('log_usage_version') and self.serv != 'testcase':
+            from asrun.contrib.log_usage import log_usage_version_unfail
+            log_usage_version_unfail(self.run['log_usage_version'], self.prof)
+
         jn = self.pid
         self.name = self.prof['nomjob'][0]
         
