@@ -93,6 +93,11 @@ class CLIENT(object):
         return self._pref
 
 
+    def set_user_preferences(self, key, value):
+        """Allow to change a preference value."""
+        self._pref[key] = value
+
+
     def init_server_config(self, force=False, refresh=False):
         """Return servers configuration from 'rcdir'/config_serveurs
         """
@@ -139,10 +144,11 @@ class CLIENT(object):
         return self._serv
 
 
-    def save_server_config(self):
+    def save_server_config(self, to=None):
         """Write 'rcdir'/config_serveurs with current values.
         """
-        content = ["""# AUTOMATICALLY GENERATED - DO NOT EDIT !
+        content = [
+"""# AUTOMATICALLY GENERATED - DO NOT EDIT !
 astkrc_version : %s
 #""" % _RC_VERSION,]
         
@@ -164,7 +170,29 @@ astkrc_version : %s
                 else:
                     content.append('%s : %s' % (key, value))
             content.append("#")
-        open(self.rcfile(SERVER_CONF), 'w').write(os.linesep.join(content))
+        to = to or self.rcfile(SERVER_CONF)
+        open(to, 'w').write(os.linesep.join(content))
+
+
+    def save_user_preferences(self, to=None):
+        """Write 'rcdir'/prefs with current values.
+        """
+        content = [
+"""# AUTOMATICALLY GENERATED - DO NOT EDIT !
+astkrc_version : %s
+#""" % _RC_VERSION,]
+        lkeys = self._pref.keys()
+        lkeys.sort()
+        for key in lkeys:
+            if key.startswith('__'):
+                continue
+            value = self._pref[key]
+            if value == "":
+                value = "_VIDE"
+            content.append('%s : %s' % (key, value))
+        content.append("")
+        to = to or self.rcfile(PREFERENCES)
+        open(to, 'w').write(os.linesep.join(content))
 
 
     def refresh_server_config(self, server_list=None):
