@@ -24,20 +24,42 @@ Tools for developpers :
 
 
 import os
+import os.path as osp
 import re
 import cPickle
 from glob import glob
 
 from asrun.installation import aster_root
 from asrun.common.i18n import _
-from asrun.mystring     import print3
+from asrun.mystring     import print3, ufmt
 from asrun.config       import ASTER_CONFIG
 from asrun.build        import ASTER_BUILD, unigest2dict
 from asrun.progress     import Progress
 
 
+class CataMessageError(Exception):
+    """Error with a catalog of messages."""
+    
+    def __init__(self, fcata, reason):
+        self.reason = reason
+        self.fcata = fcata
+
+    def __str__(self):
+        return ufmt(_(u"%s: %s, error: %s"),
+            self.__class__.__name__, self.fcata, self.reason)
+
+
 class MessageError(Exception):
-    pass
+    """Error on a message."""
+    
+    def __init__(self, msgid, reason):
+        self.reason = reason
+        self.msgid = msgid
+
+    def __str__(self):
+        return "%s: %s, error: %s" \
+            % (self.__class__.__name__, self.msgid, self.reason)
+
 
 class MESSAGE_MANAGER(object):
     """Classe pour récupérer des informations sur le catalogue de messages.
@@ -55,22 +77,22 @@ class MESSAGE_MANAGER(object):
         if type(surch_pyt) not in (list, tuple):
             surch_pyt = [surch_pyt,]
         self.repref          = repref
-        self.fort            = [os.path.join(repref, rep) for rep in fort]
-        self.pyt             = os.path.join(repref, pyt)
-        self.surch_fort      = [os.path.abspath(d) for d in surch_fort]
-        self.surch_pyt       = [os.path.abspath(d) for d in surch_pyt]
+        self.fort            = [osp.join(repref, rep) for rep in fort]
+        self.pyt             = osp.join(repref, pyt)
+        self.surch_fort      = [osp.abspath(d) for d in surch_fort]
+        self.surch_pyt       = [osp.abspath(d) for d in surch_pyt]
         self.verbose         = verbose
         self.debug           = debug
         self.force           = force
         self.message_dir     = 'Messages'
-        self.cache_dict      = cache_dict or os.path.join('/tmp', 'messages_dicts.pick')
+        self.cache_dict      = cache_dict or osp.join('/tmp', 'messages_dicts.pick')
         self.ignore_comments = ignore_comments
-        self.wrk_fort        = os.path.join(os.getcwd(), 'F')
-        self.wrk_pyt         = os.path.join(os.getcwd(), 'PY')
+        self.wrk_fort        = osp.join(os.getcwd(), 'F')
+        self.wrk_pyt         = osp.join(os.getcwd(), 'PY')
         
         self.unig            = unig
         # init ASTER_CONFIG, ASTER_BUILD objects
-        fconf = os.path.join(self.repref, 'config.txt')
+        fconf = osp.join(self.repref, 'config.txt')
         self.conf_obj  = ASTER_CONFIG(fconf, run=None)
         self.build_obj = ASTER_BUILD(run=None, conf=self.conf_obj)
         if unig:
@@ -91,7 +113,7 @@ class MESSAGE_MANAGER(object):
 
     def _filename_cata(self, cata):
         """Retourne le nom du fichier associé à un catalogue."""
-        name = os.path.join(self.pyt, self.message_dir, cata + '.py')
+        name = osp.join(self.pyt, self.message_dir, cata + '.py')
         return name
 
 
@@ -99,21 +121,21 @@ class MESSAGE_MANAGER(object):
         """Retourne modelisa5 à partir de MODELISA5_46"""
         mat = re.search('([A-Z]+[0-9]*)_([0-9]+)', msgid)
         if mat == None:
-            raise MessageError, 'invalid message id : %s' % msgid
+            raise MessageError(msgid, _(u'invalid message id'))
         cata, num = mat.groups()
         return self._filename_cata(cata.lower()), int(num)
 
 
     def _filename2id(self, fcata, num):
         """Retourne MODELISA5_46 à partir de modelisa5"""
-        return '%s_%d' % (os.path.splitext(os.path.basename(fcata))[0].upper(), num)
+        return '%s_%d' % (osp.splitext(osp.basename(fcata))[0].upper(), num)
 
 
     def makedirs(self):
         """Crée les répertoires pour les fichiers modifiés
         """
         for d in (self.wrk_fort, self.wrk_pyt):
-            if not os.path.isdir(d):
+            if not osp.isdir(d):
                 os.makedirs(d)
 
 
@@ -121,28 +143,28 @@ class MESSAGE_MANAGER(object):
         """Retourne la liste des catalogues de messages.
         """
         re_mess = re.compile('#@.*Messages')
-        s_cata = set(glob(os.path.join(self.pyt, self.message_dir, '*.py')))
+        s_cata = set(glob(osp.join(self.pyt, self.message_dir, '*.py')))
         s_suppr = set()
         l_surch = []
         # ajouter la surcharge et retirer le catalogue d'origine
         for dsrc in self.surch_pyt:
-            for f in glob(os.path.join(dsrc, '*.py')) + glob(os.path.join(dsrc, '*', '*.py')):
+            for f in glob(osp.join(dsrc, '*.py')) + glob(osp.join(dsrc, '*', '*.py')):
                 txt = open(f, 'r').read()
                 if re_mess.search(txt):
-                    l_surch.append(os.path.abspath(f))
-                    fsup = os.path.join(self.pyt, self.message_dir, os.path.basename(f))
-                    if os.path.exists(fsup):
+                    l_surch.append(osp.abspath(f))
+                    fsup = osp.join(self.pyt, self.message_dir, osp.basename(f))
+                    if osp.exists(fsup):
                         s_suppr.add(fsup)
         s_cata.update(l_surch)
         if len(l_surch) > 0:
             print3('%5d catalogues en surcharge : ' % len(l_surch))
             print3(os.linesep.join(l_surch))
 
-        s_cata = set([os.path.abspath(f) for f in s_cata \
-                if not os.path.basename(f) in ['__init__.py', 'context_info.py', 'fermetur.py']])
+        s_cata = set([osp.abspath(f) for f in s_cata \
+                if not osp.basename(f) in ['__init__.py', 'context_info.py', 'fermetur.py']])
         l_suppr = []
         if self.unig and len(self.unig['py']) > 0:
-            l_suppr = [os.path.abspath(os.path.join(self.repref, f)) \
+            l_suppr = [osp.abspath(osp.join(self.repref, f)) \
                                             for f in self.unig['py'] if f.find(self.message_dir) > -1]
             s_suppr.update(l_suppr)
         l_suppr = list(s_suppr)
@@ -161,15 +183,20 @@ class MESSAGE_MANAGER(object):
         print3('%5d catalogues dans %s + %s' \
                 % (len(self.l_cata), self.pyt, self.surch_pyt))
         all_msg = []
+        error_occurs = False
         for f in self.l_cata:
             try:
                 cata = CATA(f)
+                cata.check()
                 all_msg.extend([self._filename2id(f, i) for i in cata])
                 if self.verbose:
                     print3(cata)
-            except MessageError, msg:
+            except CataMessageError, msg:
+                error_occurs = True
                 print3(msg)
                 self.l_cata.remove(f)
+        if error_occurs:
+            raise CataMessageError(_(u"global"), _(u"errors occurred!"))
         all_msg = set(all_msg)
         
         # messages jamais appelés
@@ -194,7 +221,7 @@ class MESSAGE_MANAGER(object):
         """
         l_regexp = []
         for cata in self.l_cata:
-            cata = os.path.splitext(os.path.basename(cata))[0]
+            cata = osp.splitext(osp.basename(cata))[0]
             l_regexp.append('%s_[0-9]+' % cata.upper())
         self.regexp = re.compile('|'.join(l_regexp))
 
@@ -214,21 +241,21 @@ class MESSAGE_MANAGER(object):
         """Retourne la liste des fichiers sources fortran/fortran90."""
         s_f = set()
         for dsrc in self.fort:
-            s_f.update(glob(os.path.join(dsrc, '*.f')))
-            s_f.update(glob(os.path.join(dsrc, '*', '*.f')))
-            s_f.update(glob(os.path.join(dsrc, '*.F')))
-            s_f.update(glob(os.path.join(dsrc, '*', '*.F')))
+            s_f.update(glob(osp.join(dsrc, '*.f')))
+            s_f.update(glob(osp.join(dsrc, '*', '*.f')))
+            s_f.update(glob(osp.join(dsrc, '*.F')))
+            s_f.update(glob(osp.join(dsrc, '*', '*.F')))
         d_f = {}
         for f in s_f:
-            assert d_f.get(os.path.basename(f)) is None, 'ERROR : %s  (old : %s)' % (f, d_f[os.path.basename(f)])
-            d_f[os.path.basename(f)] = f
+            assert d_f.get(osp.basename(f)) is None, 'ERROR : %s  (old : %s)' % (f, d_f[osp.basename(f)])
+            d_f[osp.basename(f)] = f
         # surcharge
         s_surch = set()
         for dsrc in self.surch_fort:
-            s_surch.update(glob(os.path.join(dsrc, '*.f')))
-            s_surch.update(glob(os.path.join(dsrc, '*', '*.f')))
-            s_surch.update(glob(os.path.join(dsrc, '*.F')))
-            s_surch.update(glob(os.path.join(dsrc, '*', '*.F')))
+            s_surch.update(glob(osp.join(dsrc, '*.f')))
+            s_surch.update(glob(osp.join(dsrc, '*', '*.f')))
+            s_surch.update(glob(osp.join(dsrc, '*.F')))
+            s_surch.update(glob(osp.join(dsrc, '*', '*.F')))
         if len(s_surch) > 0:
             l_surch = list(s_surch)
             l_surch.sort()
@@ -237,7 +264,7 @@ class MESSAGE_MANAGER(object):
         # retirer des sources originaux ceux de la surcharge...
         s_suppr = set()
         for f in s_surch:
-            fexist = d_f.get(os.path.basename(f))
+            fexist = d_f.get(osp.basename(f))
             if fexist:
                 s_suppr.add(fexist)
                 if self.verbose: print3('suppression :', fexist)
@@ -246,14 +273,14 @@ class MESSAGE_MANAGER(object):
             iunig = 0
             for f in self.unig['f'] + self.unig['f90']:
                 iunig += 1
-                s_suppr.add(d_f.get(os.path.basename(f), ''))
+                s_suppr.add(d_f.get(osp.basename(f), ''))
                 if self.verbose: print3('suppression :', f)
             if iunig > 0:
                 print3('%5d source(s) supprime(s).' % iunig)
         
         s_f.difference_update(s_suppr)
         s_f.update(s_surch)
-        l_f = [os.path.abspath(f) for f in s_f]
+        l_f = [osp.abspath(f) for f in s_f]
         l_f.sort()
         return l_f
 
@@ -262,8 +289,8 @@ class MESSAGE_MANAGER(object):
         """Retourne la liste des fichiers python
         """
         s_pyt = set()
-        s_pyt.update(glob(os.path.join(self.pyt, '*.py')))
-        s_pyt.update(glob(os.path.join(self.pyt, '*', '*.py')))
+        s_pyt.update(glob(osp.join(self.pyt, '*.py')))
+        s_pyt.update(glob(osp.join(self.pyt, '*', '*.py')))
         d_py = {}
         for f in s_pyt:
             key = self.build_obj.GetCModif('py', f)
@@ -272,8 +299,8 @@ class MESSAGE_MANAGER(object):
         # surcharge
         s_surch = set()
         for dsrc in self.surch_pyt:
-            s_surch.update(glob(os.path.join(dsrc, '*.py')))
-            s_surch.update(glob(os.path.join(dsrc, '*', '*.py')))
+            s_surch.update(glob(osp.join(dsrc, '*.py')))
+            s_surch.update(glob(osp.join(dsrc, '*', '*.py')))
         if len(s_surch) > 0:
             l_surch = list(s_surch)
             l_surch.sort()
@@ -292,7 +319,7 @@ class MESSAGE_MANAGER(object):
             iunig = 0
             for f in self.unig['py']:
                 iunig += 1
-                fabs = os.path.abspath(os.path.join(self.repref, f))
+                fabs = osp.abspath(osp.join(self.repref, f))
                 key = self.build_obj.GetCModif('py', fabs)
                 s_suppr.add(d_py.get(key, ''))
                 if self.verbose: print3('suppression :', fabs)
@@ -301,7 +328,7 @@ class MESSAGE_MANAGER(object):
 
         s_pyt.difference_update(s_suppr)
         s_pyt.update(s_surch)
-        l_pyt = [os.path.abspath(f) for f in s_pyt]
+        l_pyt = [osp.abspath(f) for f in s_pyt]
         l_pyt.sort()
         return l_pyt
 
@@ -314,23 +341,31 @@ class MESSAGE_MANAGER(object):
         except IOError, msg:
             print3(_(u'Error with file %s : %s') % (fich, msg))
             return []
-        ext = os.path.splitext(fich)[-1]
+        ext = osp.splitext(fich)[-1]
         txt = clean_source(txt, ext, ignore_comments=self.ignore_comments, wrap=True)
         
-        if os.path.splitext(fich)[-1] != '.py':
-            expr  = 'CALL\s+(U2ME|UTEXC).*?,[ \'\"]+(.*?)[\'\" ]+[,\)]+'
+        if osp.splitext(fich)[-1] != '.py':
+            expr  = 'CALL\s+(U2ME|UTEXC).*?\((.*?),[ \'\"]+(.*?)[\'\" ]+[,\)]+'
         else:
-            expr = '(UTMESS|GetText)\s*\(.*?,[ \'\"]+(.*?)[\'\" ]+[,\)]+'
+            expr = '(UTMESS|GetText)\s*\((.*?).*?,[ \'\"]+(.*?)[\'\" ]+[,\)]+'
         all_msg = re.findall(expr, txt)
         l_msg = []
         for found in all_msg:
-            sub, msg = found
+            sub, typ, msg = found
             if msg.startswith('FERMETUR_'):
                 pass
             elif re.search('^[A-Z0-9]+_[0-9]+$', msg) is None:
-                print3('Invalid', msg, fich)
+                print3("Invalid message id ('%s') in file %s" % (msg, fich))
             else:
-                l_msg.append(msg)
+                mattyp = re.search('[\'\" ]+(.*?)[\+\'\" ]+', typ)
+                # variables and numbers (for exception) are allowed
+                if mattyp is not None and \
+                   mattyp.group(1) not in ('', 'A', 'I', 'E', 'S', 'F'):
+                   # may be '' for example STY//'+'
+                    print3("Invalid message type (%s) for message '%s' in file %s" \
+                        % (mattyp.group(1), msg, fich))
+                else:
+                    l_msg.append(msg)
 #      l_msg = self.regexp.findall(txt)
         
         # verif
@@ -350,7 +385,7 @@ class MESSAGE_MANAGER(object):
             message : liste des fichiers appelant ce message
         """
         # est-ce dans le cache ?
-        if not self.force and os.path.isfile(self.cache_dict) \
+        if not self.force and osp.isfile(self.cache_dict) \
                                 and os.stat(self.cache_dict).st_size > 0:
             if self.verbose:
                 print3('Load dicts from cache (%s)...' % self.cache_dict)
@@ -405,12 +440,12 @@ class MESSAGE_MANAGER(object):
         new_f = self._filename_cata(dest.lower())
         
         # have these catalogues been already changed ?
-        fmod = os.path.join(self.wrk_pyt, os.path.basename(old_f))
-        if os.path.isfile(fmod):
+        fmod = osp.join(self.wrk_pyt, osp.basename(old_f))
+        if osp.isfile(fmod):
             print3('from %s' % fmod)
             old_f = fmod
-        fmod = os.path.join(self.wrk_pyt, os.path.basename(new_f))
-        if os.path.isfile(fmod):
+        fmod = osp.join(self.wrk_pyt, osp.basename(new_f))
+        if osp.isfile(fmod):
             print3('from %s' % fmod)
             new_f = fmod
             
@@ -421,22 +456,22 @@ class MESSAGE_MANAGER(object):
             print3(new_cata)
         new_num = new_cata.get_new_id(reuse_hole)
         if new_num < 0:
-            raise MessageError,  'no message id available in %s' % new_f
+            raise CataMessageError(new_f, _(u'no message id available in this catalog'))
         newid = self._filename2id(new_f, new_num)
         
         # check message existence
         if old_cata[old_num] == None:
-            raise MessageError, 'message %s inexistant !' % oldid
+            raise MessageError(oldid, _(u'unknown message'))
         
         new_cata[new_num] = old_cata[old_num]
         del old_cata[old_num]
 
         # write modified catalogues
         self.makedirs()
-        fout = os.path.join(self.wrk_pyt, os.path.basename(old_f))
+        fout = osp.join(self.wrk_pyt, osp.basename(old_f))
         content = old_cata.get_content()
         open(fout, 'w').write(content)
-        fout = os.path.join(self.wrk_pyt, os.path.basename(new_f))
+        fout = osp.join(self.wrk_pyt, osp.basename(new_f))
         content = new_cata.get_content()
         open(fout, 'w').write(content)
         print3('Nouveau fichier : %s' % fout)
@@ -444,18 +479,18 @@ class MESSAGE_MANAGER(object):
         # modify source using 'oldid' message
         l_src = self.d_msg_call.get(oldid, [])
         for f in l_src:
-            ext = os.path.splitext(f)[-1]
+            ext = osp.splitext(f)[-1]
             rdest = self.wrk_fort
             if ext == '.py':
                 rdest = self.wrk_pyt
             # already changed ?
-            fmod = os.path.join(rdest, os.path.basename(f))
-            if os.path.isfile(fmod):
+            fmod = osp.join(rdest, osp.basename(f))
+            if osp.isfile(fmod):
                 print3('from %s' % fmod)
                 f = fmod
-            txt = open(os.path.join(self.repref, f), 'r').read()
+            txt = open(osp.join(self.repref, f), 'r').read()
             new = re.sub('%s([\'\"]+)' % oldid, newid + r'\1', txt)
-            fout = os.path.join(rdest, os.path.basename(f))
+            fout = osp.join(rdest, osp.basename(f))
             open(fout, 'w').write(new)
             print3('Nouveau fichier : %s' % fout)
 
@@ -540,7 +575,7 @@ class CATA:
             self.cata_msg = d['cata_msg']
         except Exception, msg:
             print3('-'*80+'\n', msg, '\n'+'-'*80)
-            raise MessageError, 'ERROR with : %s' % self.fcata
+            raise CataMessageError(self.fcata, _(u'unable to import the file'))
 
 
     def get_nb_msg(self):
@@ -582,7 +617,7 @@ class CATA:
         """Ajoute le message 'msg' à l'indice 'key'.
         """
         if self[key] != None:
-            raise MessageError, 'message %s already exists !' % key
+            raise MessageError(key, _(u'message already exists !'))
         self.cata_msg[key] = msg
 
 
@@ -590,15 +625,15 @@ class CATA:
         """Supprime le message d'indice 'key'.
         """
         if self[key] == None:
-            raise MessageError, 'message %s does not exist !' % key
+            raise MessageError(key, _(u'this message does not exist !'))
         del self.cata_msg[key]
 
 
     def __repr__(self):
         """Résumé du catalogue.
         """
-        return '%3d messages (last=%3d, next=%3d) dans %s' % \
-                (self.get_nb_msg(), self.get_last_id(), self.get_new_id(), self.fcata)
+        return ufmt(_(u'%3d messages (last=%3d, next=%3d) in %s'),
+                self.get_nb_msg(), self.get_last_id(), self.get_new_id(), self.fcata)
 
 
     def __iter__(self):
@@ -607,6 +642,24 @@ class CATA:
         return iter(self.cata_msg)
 
 
+    def check(self):
+        """Vérifie le texte des messages."""
+        def_args = {}
+        for i in range(1,100):
+            def_args['i%d' % i] = 99999999
+            def_args['r%d' % i] = 9.9999E99
+            def_args['k%d' % i] = 'xxxxxx'
+        def_args['ktout'] = "all strings !"
+        error = []
+        for num, msg in self.cata_msg.items():
+            try:
+                txt = msg % def_args
+            except:
+                error.append(ufmt(_(u'message #%s invalid : %s'), num, msg))
+        if len(error) > 0:
+            raise CataMessageError(self.fcata, os.linesep.join(error))
+
+
     def get_cmodif(self):
         """Retourne la carte MODIF.
         """
@@ -618,7 +671,7 @@ class CATA:
                 break
         fobj.close()
         if cmodif == None:
-            raise MessageError, 'invalid header "#@ MODIF/AJOUT..." in %s' % self.fcata
+            raise CataMessageError(self.fcata, _(u'invalid header "#@ MODIF/AJOUT..."'))
         return cmodif
 
 
@@ -655,11 +708,11 @@ def GetMessageInfo(run, *args):
     """
     if not run.get('aster_vers'):
         run.parser.error(_(u"You must define 'default_vers' in 'aster' configuration file or use '--vers' option."))
-    REPREF = os.path.join(aster_root, run['aster_vers'])
+    REPREF = osp.join(aster_root, run['aster_vers'])
     if not run.get('config'):
-        fconf = os.path.join(REPREF, 'config.txt')
+        fconf = osp.join(REPREF, 'config.txt')
     else:
-        fconf = os.path.abspath(run['config'])
+        fconf = osp.abspath(run['config'])
     conf = ASTER_CONFIG(fconf, run)
 
     if run['nolocal']:
@@ -692,7 +745,7 @@ def GetMessageInfo(run, *args):
         surch_pyt = surch_pyt.split(',')
     
     msgman = MESSAGE_MANAGER(repref=REPREF, fort=bibfor, pyt=bibpyt, 
-                            cache_dict=os.path.join(run['cache_dir'], 'messages_dicts.pick'),
+                            cache_dict=osp.join(run['cache_dir'], 'messages_dicts.pick'),
                             force=run['force'], verbose=run['verbose'],
                             debug=run['debug'],
                             surch_fort=surch_fort,
@@ -702,7 +755,10 @@ def GetMessageInfo(run, *args):
     msgman.read_cata()
     
     if action == 'check':
-        unused, not_found = msgman.check_cata()
+        try:
+            unused, not_found = msgman.check_cata()
+        except CataMessageError, msg:
+            run.Sortie(4)
         if not run['silent']:
             print3('Messages inutilises :')
             print3(' '.join(unused))
