@@ -88,7 +88,14 @@ class DistributionTask(Task):
     facmtps = 0.
     cpresok = False
     REPREF = reptest = resutest = flashdir = ""
-       
+
+
+    def _mess_timeout(self, dt, timeout, job, refused):
+        """Emit a message when timeout occurs."""
+        self.run.Mess(ufmt(_(u"no submission for last %.0f s (timeout %.0f s), job '%s' " \
+            "cancelled after %d attempts."), dt, timeout, job, refused))
+
+
     def execute(self, items, **kwargs):
         """Function called for each group of items of the stack.
         """
@@ -213,8 +220,7 @@ class DistributionTask(Task):
                 self.queue_put((job, opts))
                 result = None
             else:
-                self.run.Mess(ufmt(_(u"no submission for last %.0f s (timeout %.0f s), job '%s' " \
-                    "cancelled after %d attempts."), dt, self.timeout, job, opts['refused']))
+                self._mess_timeout(dt, self.timeout, job, opts['refused'])
         return result
 
     def start_failed(self, job, opts, itemid, msg):
@@ -267,6 +273,12 @@ class DistribTestTask(DistributionTask):
         nbnook (indiced by threadid)
         test_result : list of (test, opts, diag, tcpu, tsys, ttot, telap)
     """
+    def _mess_timeout(self, dt, timeout, job, refused):
+        """Emit a message when timeout occurs."""
+        self.run.Mess(ufmt(_(u"no submission for last %.0f s " \
+            "(timeout %.0f s, equal to the time requested by the main job, named 'astout'), " \
+            "job '%s' cancelled after %d attempts."), dt, timeout, job, refused))
+
     def pre_exec(self, **kwargs):
         """Function called at the beginning of execute.
         """
@@ -347,6 +359,12 @@ class DistribParametricTask(DistributionTask):
     # declare attrs
     exec_result = keywords = resudir = None
     
+    def _mess_timeout(self, dt, timeout, job, refused):
+        """Emit a message when timeout occurs."""
+        self.run.Mess(ufmt(_(u"no submission for last %.0f s " \
+            "(timeout %.0f s, equal to 2 * the time requested by the main job), " \
+            "job '%s' cancelled after %d attempts."), dt, timeout, job, refused))
+
     def create_calcul(self, job, opts, itemid, pid):
         """Create a (derived) instance of ASTER_CALCUL.
         """
