@@ -42,6 +42,7 @@ from asrun.astout       import RunAstout
 from asrun.parametric   import Parametric
 from asrun.common_func  import get_tmpname
 from asrun.common.utils import listsurcharge, NO_VALUES
+from asrun.toolbox      import MakeShared
 
 
 def SetParser(run):
@@ -53,17 +54,23 @@ def SetParser(run):
         'run'       : {
             'method' : RunAster,
             'syntax' : '[options] profile',
-            'help'   : _(u'execute the execution described by the profile (default action)')
+            'help'   : _(u'Execute the execution described by the profile (default action)')
         },
         'quick'     : {
             'method' : StartNow,
             'syntax' : '[options] file1 [file2 [...]]',
-            'help'   : _(u'start quickly an execution using the files given in arguments')
+            'help'   : _(u'Start quickly an interactive execution using the files given in arguments')
+        },
+        'make_shared' : {
+            'method' : MakeShared,
+            'syntax' : '--output=FILE [src1 [...]] srcN',
+            'help'   : _(u'Produce a shared library named FILE by compiling the '
+                'source files src1... srcN. Typically used to build a UMAT library.'),
         },
     }
     run.SetActions(
             actions_descr = acts_descr,
-            actions_order = ['run', 'quick'],
+            actions_order = ['run', 'quick', 'make_shared'],
             group_options = False,
             options_descr = {}
     )
@@ -150,7 +157,7 @@ def RunAster(run, *args):
     # do not reinitialize rep_trav if 
     if prof['prep_env'][0] not in NO_VALUES:
         run.Delete(reptrav)
-        run.MkDir(reptrav)
+        run.MkDir(reptrav, chmod=0700)
     if prof['detr_rep_trav'][0] not in NO_VALUES:
         run.ToDelete(reptrav)
 
@@ -295,6 +302,9 @@ def RunAster(run, *args):
         run.MkDir(repact)
         kargs = { 'exe' : exetmp, 'cmde' : cmdetmp, 'ele' : eletmp, }
         kargs['cata'] = [l['path'] for l in prof.Get('D', typ='cata')]
+        lfun = prof.Get('D', typ='unig')
+        if lfun:
+            kargs['unigest'] = build.GetUnigest(lfun[0]['path'])
         if prof.Get('D', typ='py'):
             kargs['py'] = [l['path'] for l in prof.Get('D', typ='py')]
         jret = build.CompilEle(REPREF, repact, **kargs)
@@ -506,8 +516,9 @@ def StartNow(run, *args):
     """
     if not run["silent"]:
         run.Mess(_(u"This functionnality is still in a beta state of development "
-                   u"and may be removed a future release. Please use --silent option "
-                   u"to ignore this alarm the next time."), '<A>_ALARM')
+                   u"and may be removed a future release, or may never be improved. "
+                   u"Please use --silent option to ignore this alarm the next time."),
+                   '<A>_ALARM')
     # ----- check argument
     if not run.get('aster_vers'):
         run.parser.error(_(u"You must define 'default_vers' in 'aster' configuration file or use '--vers' option."))
