@@ -194,7 +194,10 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
         run.Mess('   cd %s' % reptrav, 'SILENT')
         run.Mess('   . %s' % osp.join(confdir, 'profile.sh'), 'SILENT')
         tmp_profile = "profile_tmp.sh"
-        open(tmp_profile, 'w').write("export PYTHONPATH=$PYTHONPATH:." + os.linesep)
+        open(tmp_profile, 'w').write("""
+export PYTHONPATH=$PYTHONPATH:.
+export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:.
+""")
         # set per version environment
         for f in conf.get_with_absolute_path('ENV_SH') + [tmp_profile]:
             run.Mess('   . %s' % f, 'SILENT')
@@ -211,6 +214,16 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
         exec pdbpy_cmd in d
         pdbpy = d['pdbpy']
         
+        if mpi_info.really():
+            if len(list_comm) > 1:
+                run.Mess(_("Running more than one comm file is not allowed in MPI mode. "
+                           "Only the first .comm will be started."), "<A>_ALARM")
+                list_comm = [list_comm[0], ]
+
+            cmdline = mpi_info.get_exec_command(run, cmdline,
+                add_tee=False,
+                env=conf.get_with_absolute_path('ENV_SH'))
+
         # print command lines
         k = 0
         for fcomm in list_comm:
@@ -218,6 +231,10 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
             cmd_2 = cmdline.replace('fort.1', fcomm)
             run.Mess(_(u'Command line %d :') % k)
             run.Mess(cmd_2, 'SILENT')
+            if mpi_info.really():
+                os.chdir(mpi_info.reptrav())
+                run.Rename(fcomm, 'fort.1')
+                break
             # how to start the Python debugger
             run.Mess(_(u'To start execution in the Python debugger you could type :'), 'SILENT')
             pdb_cmd = cmd_2.replace(osp.join('.', osp.basename(exetmp)),
@@ -262,8 +279,9 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
             cmd.extend(['-%s %s' % (k, v) for k, v in cmd_memtps.items()])
             pos_memtps = -1
             
-            ldbg.append('run '+' '.join(cmd))
-            cmd = getdbgcmd(cmd_dbg, osp.basename(exetmp), '', ldbg)
+            cmd_args = ' '.join(cmd)
+            ldbg.append('run ' + cmd_args)
+            cmd = getdbgcmd(cmd_dbg, osp.basename(exetmp), '', ldbg, cmd_args)
         else:
             add_tee = True
             cmd.insert(0, osp.join('.', osp.basename(exetmp)))
@@ -403,7 +421,7 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
                     core = lcor[0]
                     run.Mess(ufmt(_(u'core file name : %s'), core))
                     cmd = getdbgcmd(cmd_dbg, osp.basename(exetmp), core,
-                            ('where', 'quit'))
+                            ('where', 'quit'), '')
                     tit = _(u'Coredump analysis')
                     run.Mess(tit, 'TITLE')
                     run.timer.Start(tit)
@@ -579,7 +597,7 @@ def copyfileR(run, df, copybase=True):
             rescue = get_tmpname(run, basename='save_results')
             run.Mess(ufmt(_(u"Saving results in a temporary directory (%s)."), rescue),
                     '<A>_COPY_RESULTS', store=True)
-            kret = run.MkDir(rescue)
+            kret = run.MkDir(rescue, chmod=0700)
             kret = run.Copy(rescue, niverr='<E>_COPY_ERROR',
                     verbose=True, *lf)
 
@@ -663,7 +681,7 @@ def build_export_from_files(run, lf, root="", with_default=True):
     return prof
 
 
-def getdbgcmd(cmd_dbg, exe, core, lcmd):
+def getdbgcmd(cmd_dbg, exe, core, lcmd, args):
     """Return the command line (as list) to run 'lcmd' in the debugger.
         @E : executable
         @C : coredump filename
@@ -682,6 +700,7 @@ def getdbgcmd(cmd_dbg, exe, core, lcmd):
     cmd = cmd.replace('@C', core)
     cmd = cmd.replace('@D', ftmp)
     cmd = cmd.replace('@d', cstr)
+    cmd = cmd.replace('@a', args)
     return [cmd]
 
 
