@@ -42,6 +42,7 @@ from asrun.system        import shell_cmd
 from asrun.common_func   import get_tmpname
 from asrun.common.utils  import YES_VALUES
 from asrun.common.sysutils import is_localhost, is_localdisplay
+from asrun.toolbox       import ConvertToHtml
 
 
 def SetParser(run):
@@ -53,37 +54,43 @@ def SetParser(run):
         'info' : {
             'method' : Info,
             'syntax' : '',
-            'help'   : _(u'returns informations from astk server configuration : '\
+            'help'   : _(u'Returns informations from astk server configuration : '\
                     'batch, interactive (yes/no, limits), compute nodes, '\
                     'versions')
         },
         'actu' : {
             'method' : Actu,
             'syntax' : 'job_number job_name mode',
-            'help'   : _(u'returns the state, diagnosis, execution node, spent '\
+            'help'   : _(u'Returns the state, diagnosis, execution node, spent '\
                     'cpu time and working directory of a job')
         },
         'edit' : {
             'method' : Edit,
             'syntax' : 'job_number job_name mode output|error DISPLAY',
-            'help'   : _(u'opens output or error file on the provided display')
+            'help'   : _(u'Opens output or error file on the provided display')
         },
         'del' : {
             'method' : Del,
             'syntax' : 'job_number job_name mode [node] [--signal=...]',
-            'help'   : _(u'kill a job and delete related files')
+            'help'   : _(u'Kill a job and delete related files')
         },
         'purge_flash' : {
             'method' : Purge,
             'syntax' : 'job_number1 [job_number2 [...]]]',
-            'help'   : _(u'delete files of jobs which are NOT in the list')
+            'help'   : _(u'Delete files of jobs which are NOT in the list')
         },
         'tail' : {
             'method' : Tail,
             'syntax' : 'job_number job_name mode fdest nb_lines [regexp]',
-            'help'   : _(u'output the last part of fort.6 file or filter lines ' \
+            'help'   : _(u'Output the last part of fort.6 file or filter lines ' \
                     'matching a pattern')
         },
+        'convert_to_html' : {
+            'method' : ConvertToHtml,
+            'syntax' : '[user@machine:]file --output=FILE',
+            'help'   : _(u'Convert a file (may be on a remote machine) into html '
+                'format and write result to FILE'),
+        },
     }
     opts_descr = {
         'signal' : {
@@ -109,7 +116,8 @@ def SetParser(run):
     title = 'Options for operations on jobs'
     run.SetActions(
             actions_descr = acts_descr,
-            actions_order = ['info', 'actu', 'edit', 'tail', 'del', 'purge_flash'],
+            actions_order = ['info', 'actu', 'edit', 'tail', 'del', 'purge_flash',
+                    'convert_to_html'],
             group_options=True, group_title=title, actions_group_title=False,
             options_descr = opts_descr,
     )
