@@ -45,9 +45,9 @@ from asrun.update       import AstkUpdate, read_version_list, download_package
 from asrun.execution    import build_test_export
 from asrun.testlist     import TestList
 from asrun.mpi          import MPI_INFO
-from asrun.toolbox      import GetInfos, ConvertToHtml, MakeShared
+from asrun.toolbox      import GetInfos
 from asrun.common_func  import get_tmpname, get_devel_param
-from asrun.dev.messages import GetMessageInfo
+from asrun.dev          import GetMessageInfo, FreeSubroutines
 from asrun.common.utils import get_list, version2tuple, tuple2version, remove_empty_dirs
 
 
@@ -133,11 +133,11 @@ def SetParser(run):
                           'some stats. move = move a message from a catalogue to another and ' \
                           'produce new catalogues and new source files.')
         },
-        'sendmail'  : {
-            'method' : SendMail,
-            'syntax' : '[--report_to=EMAIL1,EMAIL2] filename',
-            'help'   : _(u'Send the content of "filename" (may be on a remote host) to '\
-                          'EMAIL1,EMAIL2,...')
+        'free_sub' : {
+            'method' : FreeSubroutines,
+            'syntax' : '[--all]',
+            'help' : _(u'Return the available numbers for the routines TE, OP, LC... ' \
+                        'Return the first 8 items except if --all is present.'),
         },
         'get_export' : {
             'method' : GetExport,
@@ -149,18 +149,6 @@ def SetParser(run):
             'syntax' : '[--output=FILE] host1 [host2 [...]]',
             'help'   : _(u'Return cpu and memory informations about given hosts'),
         },
-        'convert_to_html' : {
-            'method' : ConvertToHtml,
-            'syntax' : '[user@machine:]file --output=FILE',
-            'help'   : _(u'Convert a file (may be on a remote machine) into html '
-                'format and write result to FILE'),
-        },
-        'make_shared' : {
-            'method' : MakeShared,
-            'syntax' : '--output=FILE [src1 [...]] srcN',
-            'help'   : _(u'Produce a shared library named FILE by compiling the '
-                'source files src1... srcN. Typically used to build a UMAT library.'),
-        },
     }
     opts_descr = {
         'local' : {
@@ -373,10 +361,10 @@ def SetParser(run):
     title = _(u'Options for maintenance operations')
     run.SetActions(
             actions_descr=acts_descr,
-            actions_order=['getop', 'getversion', 'get', 'show', 'diff', 'get_export', \
-                    'make', 'update', 'auto_update', 'astk_update', \
-                    'diag', 'list', 'ctags', 'messages', 'make_shared', 'sendmail', \
-                    'get_infos', 'convert_to_html'],
+            actions_order=['show', 'get', 'diff', 'getop', 'get_export',
+                    'list', 'diag', 'messages', 'get_infos', 
+                    'getversion', 'make', 'update', 'auto_update', 'astk_update',
+                    'ctags', 'free_sub'],
             group_options=True, group_title=title, actions_group_title=False,
             options_descr=opts_descr
     )
@@ -755,13 +743,20 @@ def MakeAster(run, *args):
             errmsg = os.linesep.join(mail)
             mail.append(run.get_important_messages(reinit=True))
             if run['report_to'] != '':
-                run.SendMail(dest=run['report_to'],
-                    text = os.linesep.join(mail),
-                    subject = 'Built of %s failed on %s' % \
-                            (run.get_version_path(run['aster_vers']), local_host))
+                subject = 'Built of %s failed on %s' % \
+                        (run.get_version_path(run['aster_vers']), local_host)
             run.Mess(errmsg, '<F>_BUILD_FAILED')
         else:
             run.ExitOnFatalError = True
+            subject = _(u'Built of %s ended successfully on %s') \
+                        % (run.get_version_path(run['aster_vers']), local_host)
+            mail.append(subject)
+            run.ExitOnFatalError = True
+            run.Mess(os.linesep.join(mail), 'OK')
+        if run['report_to'] != '':
+            run.SendMail(dest=run['report_to'],
+                text = os.linesep.join(mail),
+                subject = subject)
     
     elif target == 'clean':
         if len(param) == 0:
@@ -927,7 +922,7 @@ except:
         if not run['verbose']:
             run.VerbEnd(kret, output=out, verbose=True)
         if kret != 0:
-            run.Mess(_(u'test of executables failed'), '<F>_BUILD_ERROR')
+            run.Mess(_(u'test of executables failed'), '<F>_BUILD_FAILED')
         run.timer.Stop(tit)
 
     # 2. ----- compile commands
@@ -1307,7 +1302,7 @@ def AutoUpdate(run, *args):
             mail.append(traceback.format_exc())
             mail.append('-'*60)
             mail.append(_(u'Exit code : %s') % msg)
-            run.Mess(os.linesep.join(mail), '<F>_UPDATE_FAILED')
+            run.Mess(os.linesep.join(mail), '<E>_UPDATE_FAILED')
         else:
             subject = _(u'Update ended successfully on %s from %s to %s') \
                         % (local_host, previous, next)
@@ -1318,6 +1313,7 @@ def AutoUpdate(run, *args):
             run.SendMail(dest=run['report_to'],
                 text = os.linesep.join(mail),
                 subject = subject)
+        run.CheckOK()
         # ----- keep intermediate releases
         if run['keep_increment']:
             CopyVersion(run, run.get_version_path(run['aster_vers']),
@@ -1597,26 +1593,6 @@ def GenCtags(run, force=False):
     os.chdir(prev)
 
 
-def SendMail(run, *args):
-    """Send the content of a file by mail.
-    """
-    # ----- check argument
-    if len(args) != 1:
-        run.parser.error(_(u"'--%s' requires one argument") % run.current_action)
-
-    # ----- content file
-    fcontent = get_tmpname(run, run['tmp_user'], basename='mail_content')
-    run.ToDelete(fcontent)
-    kret = run.Copy(fcontent, args[0], niverr='<F>_PROFILE_COPY')
-    
-    if run['report_to'] == '':
-        run.Mess(_(u"no email address provided !"), '<F>_ERROR')
-    
-    run.SendMail(dest    = run['report_to'],
-                text    = open(fcontent, 'r').read(),
-                subject = 'From as_run/SendMail')
-
-
 def GetExport(run, *args):
     """Build an export file to run a testcase and print it to stdout.
     """
