@@ -148,6 +148,8 @@ exit `grep -a %(var)s fort.6 | head -1 | sed -e 's/%(var)s=//'`""" % dict_val
         
         dict_mpi_args = {
             'mpirun_cmd'         : run['mpirun_cmd'],
+            'mpi_ini'            : run.get('mpi_ini'),
+            'mpi_end'            : run.get('mpi_end'),
             'mpi_get_procid_cmd' : run['mpi_get_procid_cmd'],
             'mpi_hostfile'       : run.get('mpi_hostfile'),
             'mpi_nbnoeud'        : self.nbnode(),
@@ -165,17 +167,17 @@ exit `grep -a %(var)s fort.6 | head -1 | sed -e 's/%(var)s=//'`""" % dict_val
         content = open(template, 'r').read() % dict_mpi_args
         run.DBG(content, all=True)
         open(mpi_script, 'w').write(content)
-        os.chmod(mpi_script, 0700)
+        os.chmod(mpi_script, 0755)
         # add comment because cpu/system times are not counted by the timer
         self._add_timer_comment(run)
         # mpirun/mpiexec
-        command = run['mpirun_cmd'] % dict_mpi_args
+        command = dict_mpi_args['mpirun_cmd'] % dict_mpi_args
         # need to initialize MPI session ?
-        if run.get('mpi_ini'):
-            command = run['mpi_ini'] % dict_mpi_args + " ; " + command
+        if dict_mpi_args['mpi_ini']:
+            command = dict_mpi_args['mpi_ini'] % dict_mpi_args + " ; " + command
         # need to close MPI session ?
-        if run.get('mpi_end'):
-            command = command + " ; " + run['mpi_end'] % dict_mpi_args
+        if dict_mpi_args['mpi_end']:
+            command = command + " ; " + dict_mpi_args['mpi_end'] % dict_mpi_args
         return command
 
 
