@@ -55,6 +55,8 @@ def ufmt(uformat, *args):
 def to_unicode(string):
     """Try to convert string into a unicode string
     """
+    if type(string) is unicode:
+        return string
     for encoding in ('utf-8', 'iso-8859-15', 'cp1252'):
         try:
             s = unicode(string, encoding)
