@@ -62,6 +62,20 @@ def in_adm_group(run):
     return is_adm
 
 
+def parse_issue_file(content):
+    """Parse the content of the issue."""
+    l_champs = ['NOMUSER', 'MAILUSER', 'UNIUSER',
+                'TITRE', 'DATE1', 'DATE2', 'VERSION', 'TYPFIC', 'TEXTE',
+                'FICASS']
+    dinf = {}
+    for ch in l_champs:
+        exp = re.compile('\@%s\@(.*)\@FIN%s\@' % (ch, ch), re.MULTILINE | re.DOTALL)
+        mat = exp.search(content)
+        if mat != None and mat.group(1).strip() != 'Non_défini':
+            dinf[ch] = mat.group(1).strip()
+    return dinf
+
+
 def SetParser(run):
     """Configure the command-line parser, add options name to store to the list,
     set actions informations.
@@ -70,18 +84,19 @@ def SetParser(run):
     acts_descr = {
         'create_issue' : {
             'method' : Creer,
-            'syntax' : 'issue_file [export_file]',
-            'help'   : _(u'insert a new issue in database and copy attached files if an export file is provided')
+            'syntax' : 'issue_file export_file',
+            'help'   : _(u'Insert a new entry in the issue tracking system and '
+                          'copy attached files if an export file is provided')
         },
         'extract_histor' : {
             'method' : Histor,
             'syntax' : '[--status=STAT] [--format=FORM] [--all_msg] input_file histor',
-            'help'   : _(u'extract the content of issues listed in `input_file` to `histor`')
+            'help'   : _(u'Extract the content of issues listed in `input_file` to `histor`')
         },
         'close_issue' : {
             'method' : Solder,
             'syntax' : '--vers=VERS histor',
-            'help'   : _(u'fill "corrVdev" or "corrVexpl" field (depends on VERS) in issues found in `histor` and eventually close them')
+            'help'   : _(u'Fill "corrVdev" or "corrVexpl" field (depends on VERS) in issues found in `histor` and eventually close them')
         },
     }
     opts_descr = {
@@ -120,7 +135,7 @@ def SetParser(run):
     title = _(u'Options for issue tracker interface')
     run.SetActions(
             actions_descr=acts_descr,
-            actions_order=['create_issue', 'extract_histor', 'close_issue'],
+            actions_order=['create_issue', 'close_issue', 'extract_histor'],
             group_options=True, group_title=title, actions_group_title=False,
             options_descr=opts_descr,
     )
@@ -129,6 +144,7 @@ def SetParser(run):
 def Creer(run, *args):
     """Create a new issue in REX database.
     """
+    # backward compatibility: 2nd argument was optionnal in astk <= 1.8.3
     if len(args) < 1 or len(args) > 2:
         run.parser.error(_(u"'--%s' requires one or two arguments") % run.current_action)
 
@@ -141,30 +157,23 @@ def Creer(run, *args):
     if not imports_succeed:
         run.Mess(_(u'Imports of REX interface failed.'), '<F>_IMPORT_ERROR')
 
-    # 1. copy export and issue files
+    # 1. copy issue file
     jn = run['num_job']
     ffich = get_tmpname(run, run['tmp_user'], basename='rex_fich')
     kret = run.Copy(ffich, args[0], niverr='<F>_COPYFILE')
-    fichetude = 0
-    if len(args) > 1:
-        fichetude = 1
-        fprof = get_tmpname(run, run['tmp_user'], basename='rex_prof')
-        kret = run.Copy(fprof, args[1], niverr='<F>_PROFILE_COPY')
 
-    # 2. parse issue file
-    fiche = open(ffich, 'r').read()
-    l_champs = ['NOMUSER', 'MAILUSER', 'UNIUSER',
-                    'TITRE', 'DATE1', 'DATE2', 'VERSION', 'TYPFIC', 'TEXTE',
-                    'FICASS']
-    d = {}
-    for ch in l_champs:
-        exp = re.compile('\@%s\@(.*)\@FIN%s\@' % (ch, ch), re.MULTILINE | re.DOTALL)
-        mat = exp.search(fiche)
-        if mat != None and mat.group(1).strip() != 'Non_défini':
-            d[ch] = mat.group(1).strip()
+    # 1b. parse issue file
+    content = open(ffich, 'r').read()
+    d = parse_issue_file(content)
     if run['debug']:
         print3('Dict issue content : ', repr(d))
 
+    fichetude = int(d.get('FICASS') is not None)
+    if fichetude == 1:
+        assert len(args) > 1, "inconsistent data" # check backward compatibility
+        fprof = get_tmpname(run, run['tmp_user'], basename='rex_prof')
+        kret = run.Copy(fprof, args[1], niverr='<F>_PROFILE_COPY')
+
     # 3. open database connection
     try:
         c = db.CONNECT('REX', rcdir=confdir, verbose=run['debug'])
