@@ -179,7 +179,7 @@ class ASTER_RUN:
             pass
 
         # ----- check for 'flasheur'
-        flash = osp.join(get_home_directory(), self.config['flash_srv'])
+        flash = osp.join(get_home_directory(), "flasheur")
         self.config['flasheur'] = flash
         # safer as osp.exists for multiple executions
         try:
@@ -305,8 +305,8 @@ class ASTER_RUN:
         import asrun.job
         import asrun.rex
         import asrun.bddetudes
-        asrun.maintenance.SetParser(self)
         asrun.execute.SetParser(self)
+        asrun.maintenance.SetParser(self)
         asrun.services.SetParser(self)
         asrun.job.SetParser(self)
         asrun.rex.SetParser(self)
@@ -455,7 +455,12 @@ class ASTER_RUN:
         from 'self.to_delete'.
         """
         # to avoid to delete current directory (it may freeze some systems...)
-        os.chdir(get_home_directory())
+        try:
+            os.chdir(get_home_directory())
+        except OSError:
+            print3(_(u"Can not change to the home directory ('%s'). "
+                      "Temporay files have not been deleted.") % get_home_directory())
+            return
         ct = time.time()
         deltat = 24*3600
         # ----- config is not set during __init__
@@ -531,13 +536,14 @@ class ASTER_RUN:
         if not label:
             return None
         dv = {}
-        for v in self["vers"].split():
-            key = osp.basename(v)
-            if dv.get(key) is not None:
-                self.Mess(_(u"%s is already known as %s (%s is ignored). Check your configuration file : %s") \
-                    % (key, dv[key], v, osp.join(confdir, "aster")), "<A>_ALARM")
-                continue
-            dv[key] = v
+        if self['vers']:
+            for v in self['vers'].split():
+                key = osp.basename(v)
+                if dv.get(key) is not None:
+                    self.Mess(_(u"%s is already known as %s (%s is ignored). Check your configuration file : %s") \
+                        % (key, dv[key], v, osp.join(confdir, "aster")), "<A>_ALARM")
+                    continue
+                dv[key] = v
         return osp.join(root, dv.get(label, label))
 
 
