@@ -24,13 +24,13 @@ Definition of ITEM class representing a MySQL item.
 
 import os
 import time
-import sha
 import datetime
 import re
 
 from asrun.myconnect    import MySQLError
 from asrun.common.i18n import _
 from asrun.mystring     import print3, convert
+from asrun.common.utils import sha1
 
 
 __verbose__ = False
@@ -557,7 +557,7 @@ class USER(ITEM):
         '_creator'        : 1,              # id de admin
         '_loginaster'     : None,
         '_organisation'   : None,
-        '_password'       : '{SHA}'+sha.sha('mot de passe par defaut').hexdigest(),
+        '_password'       : '{SHA}'+sha1('mot de passe par defaut').hexdigest(),
         '_phone'          : None,
         '_realname'       : None,
         '_roles'          : None,
