@@ -54,10 +54,16 @@ def SetParser(run):
             'syntax' : 'user@mach:/nom_profil.export',
             'help'   : _(u'call a server to start an execution (calling as_run --serv on the server)')
         },
+        'sendmail'  : {
+            'method' : SendMail,
+            'syntax' : '[--report_to=EMAIL1,EMAIL2] filename',
+            'help'   : _(u'Send the content of "filename" (may be on a remote host) to '\
+                          'EMAIL1,EMAIL2,...')
+        },
     }
     run.SetActions(
             actions_descr = acts_descr,
-            actions_order = ['serv', 'call_server'],
+            actions_order = ['serv', 'call_server', 'sendmail'],
             group_options=False,
             options_descr = {},
     )
@@ -81,7 +87,7 @@ def Serv(run, *args):
 def Start(run, *args):
     """Call a server to start a calculation : call --serv option on the
     local or remote server.
-    This option is intended to be called on the client machine (directly
+    This option is intended to be called on a client machine (directly
     by the gui for example).
     """
     # ----- check argument
@@ -104,3 +110,22 @@ def Start(run, *args):
     print3("JOBID=%s QUEUE=%s" % (jobid, queue))
     run.Sortie(iret)
 
+
+def SendMail(run, *args):
+    """Send the content of a file by mail.
+    """
+    # ----- check argument
+    if len(args) != 1:
+        run.parser.error(_(u"'--%s' requires one argument") % run.current_action)
+
+    # ----- content file
+    fcontent = get_tmpname(run, run['tmp_user'], basename='mail_content')
+    run.ToDelete(fcontent)
+    kret = run.Copy(fcontent, args[0], niverr='<F>_PROFILE_COPY')
+    
+    if run['report_to'] == '':
+        run.Mess(_(u"no email address provided !"), '<F>_ERROR')
+    
+    run.SendMail(dest    = run['report_to'],
+                text    = open(fcontent, 'r').read(),
+                subject = 'From as_run/SendMail')
