@@ -707,7 +707,7 @@ class ASTER_SYSTEM:
         return out.lower().find('text') > -1 and out.find('CR') > -1
 
 
-    def MkDir(self, rep, niverr=None, verbose=None):
+    def MkDir(self, rep, niverr=None, verbose=None, chmod=0755):
         """Create the directory 'rep' (mkdir -p ...)
         """
         if niverr == None:
@@ -717,7 +717,10 @@ class ASTER_SYSTEM:
         iret = 0
         dico = self.filename2dict(rep)
         if self.IsRemote(rep):
-            cmd = 'mkdir -p '+dico['name']
+            cmd = 'mkdir -p %(dir)s ; chmod %(chmod)o %(dir)s' % {
+                'dir' : dico['name'],
+                'chmod' : chmod,
+            }
             iret, out = self.Shell(cmd, dico['mach'], dico['user'], verbose=verbose)
         else:
             self.VerbStart(ufmt(_(u'creating directory %s'), dico['name']), verbose)
@@ -733,6 +736,7 @@ class ASTER_SYSTEM:
                                        dico['name']))
                     else:
                         os.makedirs(dico['name'])
+                        os.chmod(dico['name'], chmod)
                 except OSError, s:
                     iret = 4
                 self.VerbEnd(iret, s, verbose)
@@ -882,7 +886,8 @@ class ASTER_SYSTEM:
             return
         dest = [s.strip() for s in dest.split(',')]
         mail_encoding = get_encoding()
-        msg = MIMEText(convert(text+sign, mail_encoding), _charset=mail_encoding)
+        content = convert(to_unicode(text) + sign, mail_encoding)
+        msg = MIMEText(content, _charset=mail_encoding)
         msg['Subject'] = convert(subject, mail_encoding)
         if author == None:
             author = '%s@%s' % (local_user, local_full_host)
