@@ -7,7 +7,7 @@ import re
 from glob import glob
 from distutils           import log, sysconfig
 from distutils.file_util import copy_file, move_file
-from distutils.dir_util  import mkpath
+from distutils.dir_util  import mkpath, copy_tree
 
 from configuration.util  import (read_rcfile, replace_rcfile, print_diff, backup_name,
                                  get_function, chmod_scripts, remove_tree, prefix2etc,
@@ -69,11 +69,16 @@ def finalize(rootdir, prefix, parameters, version, **options):
       # exceptions
       ignore_list.add(osp.join(parameters['server_confdir'], 'aster_profile.sh'))
       for old_file in os.listdir(parameters['server_confdir']):
+         old = osp.join(parameters['server_confdir'], old_file)
          new = osp.join(newdir, old_file)
-         if new in ignore_list or osp.join(parameters['server_confdir'], old_file) in ignore_list:
+         if new in ignore_list or old in ignore_list:
             continue
          if not osp.exists(new):
-            copy_file(osp.join(parameters['server_confdir'], old_file), new)
+            if osp.isfile(old):
+                copy_file(old, new)
+            else:
+                os.makedirs(new)
+                copy_tree(old, new)
 
    # restore client configuration file
    if parameters['client_confdir'] != '':
